summaryrefslogtreecommitdiff
path: root/InCallUI
diff options
context:
space:
mode:
authorTyler Gunn <tgunn@google.com>2014-08-08 14:59:57 -0700
committerTyler Gunn <tgunn@google.com>2014-08-08 14:59:57 -0700
commit4ed232b7beb54b1df58eeee47846a8f86741572d (patch)
treec06a808f60f069b63da87041a6688c1c5a2f400c /InCallUI
parent660b6ef83695d181ac490e132ffa77085936b9b2 (diff)
VT preview camera setup. (2/2)
Changing the means by which the preview camera is set for video calls. Previously, an assumption was made that as soon as the camera is set on the provider, the camera capabilities would be returned. Changed so that instead the InCall-UI will explicitly request the camera capabilities after the camera is set to match the original intended camera setup flow. Change-Id: I6992e68e1efc0d8abf017fdc62f932bd0b9fce03
Diffstat (limited to 'InCallUI')
-rw-r--r--InCallUI/src/com/android/incallui/CallButtonPresenter.java1
-rw-r--r--InCallUI/src/com/android/incallui/VideoCallPresenter.java3
2 files changed, 3 insertions, 1 deletions
diff --git a/InCallUI/src/com/android/incallui/CallButtonPresenter.java b/InCallUI/src/com/android/incallui/CallButtonPresenter.java
index 15a64b63f..878a4d9a1 100644
--- a/InCallUI/src/com/android/incallui/CallButtonPresenter.java
+++ b/InCallUI/src/com/android/incallui/CallButtonPresenter.java
@@ -254,6 +254,7 @@ public class CallButtonPresenter extends Presenter<CallButtonPresenter.CallButto
String cameraId = mInCallCameraManager.getActiveCameraId();
if (cameraId != null) {
videoCall.setCamera(cameraId);
+ videoCall.requestCameraCapabilities();
}
getUi().setSwitchCameraButton(!useFrontFacingCamera);
}
diff --git a/InCallUI/src/com/android/incallui/VideoCallPresenter.java b/InCallUI/src/com/android/incallui/VideoCallPresenter.java
index 77aa4ac0c..077aa25ee 100644
--- a/InCallUI/src/com/android/incallui/VideoCallPresenter.java
+++ b/InCallUI/src/com/android/incallui/VideoCallPresenter.java
@@ -397,7 +397,7 @@ public class VideoCallPresenter extends Presenter<VideoCallPresenter.VideoCallUi
ui.showVideoUi(true);
InCallPresenter.getInstance().setInCallAllowsOrientationChange(true);
// Communicate the current camera to telephony; expect to get call-back with camera
// capabilities.
if (mVideoCall != null) {
// Do not reset the surfaces if we just restarted the activity due to an orientation
@@ -408,6 +408,7 @@ public class VideoCallPresenter extends Presenter<VideoCallPresenter.VideoCallUi
mPreviewSurfaceState = PreviewSurfaceState.CAMERA_SET;
mVideoCall.setCamera(mInCallCameraManager.getActiveCameraId());
+ mVideoCall.requestCameraCapabilities();
if (ui.isDisplayVideoSurfaceCreated()) {
mVideoCall.setDisplaySurface(ui.getDisplayVideoSurface());
@@ -397,7 +397,7 @@ public class VideoCallPresenter extends Presenter<VideoCallPresenter.VideoCallUi
ui.showVideoUi(true);
InCallPresenter.getInstance().setInCallAllowsOrientationChange(true);
- // Communicate the current camera to telephony; expect to get call-back with camera
+ // Communicate the current camera to telephony and make a request for the camera
// capabilities.
if (mVideoCall != null) {